==> ribosomeProfilingQC_1.0.3.tgz: ribosomeProfilingQC/NEWS.md <==
# CHANGES IN VERSION 1.0.3

* Fix the error "CIGAR is empty after qnarrowing".

# CHANGES IN VERSION 1.0.2

* update vignette to fix the typos.

# CHANGES IN VERSION 1.0.1

* update vignette by adding background colors for better understanding the pipeline.

# CHANGES IN VERSION 0.99.91

* change Y-axis lable from Frequence to Frequency for plot Distance2Codon.
* update vignette.

# CHANGES IN VERSION 0.99.9

* reset the test_estimatePsite.

# CHANGES IN VERSION 0.99.8

* decrease the testing time.

# CHANGES IN VERSION 0.99.6

* fix the warning missing link of plot in plotTE.

# CHANGES IN VERSION 0.99.5

* update ggBar function to accept more colors.
* update readsEndPlot function with shift parameter.
* update plotDistance2Codon function with a range of plot window
* add codonUsage function.

# CHANGES IN VERSION 0.99.4

* update the description in DESCRIPTION.
* update help files.

# CHANGES IN VERSION 0.99.3

* change the link from AtomicList to AtomicList-class and RUVs-methods to RUVs.
* shorter lines < 80 characters.
* spead up coverageDepth

# CHANGES IN VERSION 0.99.2

* remove .DS_Store

# CHANGES IN VERSION 0.99.1

* decrease the size of the package
* simplify and add parameter anchor for the estimatePsite function.
* add parameter normByLibSize for function translationalEfficiency
* add more test files.
* update documentations.

# CHANGES IN VERSION 0.99.0

* Submit to Bioconductor.

# CHANGES IN VERSION 0.0.6

* Remove sapply.

# CHANGES IN VERSION 0.0.1

* Create the package.

==> ribosomeProfilingQC_1.6.0.tgz: ribosomeProfilingQC/NEWS.md <==
# CHANGES IN VERSION 1.3.4

* add rmarkdown as suggest package.

# CHANGES IN VERSION 1.3.3

* add github action.

# CHANGES IN VERSION 1.3.2

* fix the issue if there is softclip in the mapping reads and the reads length
is smaller than shfit range.

# CHANGES IN VERSION 1.3.1

* keep the raw counts for countReads.

# CHANGES IN VERSION 1.1.6

* fix the issue in shiftReads for reads width and readsEndPlot for seqlevels.

# CHANGES IN VERSION 1.1.5

* Update documentation about the R version requirement.

# CHANGES IN VERSION 1.1.4

* Update authorship.

# CHANGES IN VERSION 1.1.3

* Fix the error "CIGAR is empty after qnarrowing".

# CHANGES IN VERSION 1.1.2

* update vignette to fix the typos.
* update plotTranscript to give more informative warning message. 

# CHANGES IN VERSION 1.1.1

* update vignette by adding background colors for better understanding 
the pipeline.

# CHANGES IN VERSION 0.99.91

* change Y-axis lable from Frequence to Frequency for plot Distance2Codon.
* update vignette.

# CHANGES IN VERSION 0.99.9

* reset the test_estimatePsite.

# CHANGES IN VERSION 0.99.8

* decrease the testing time.

# CHANGES IN VERSION 0.99.6

* fix the warning missing link of plot in plotTE.

# CHANGES IN VERSION 0.99.5

* update ggBar function to accept more colors.
* update readsEndPlot function with shift parameter.
* update plotDistance2Codon function with a range of plot window
* add codonUsage function.

# CHANGES IN VERSION 0.99.4

* update the description in DESCRIPTION.
* update help files.

# CHANGES IN VERSION 0.99.3

* change the link from AtomicList to AtomicList-class and RUVs-methods to RUVs.
* shorter lines < 80 characters.
* spead up coverageDepth

# CHANGES IN VERSION 0.99.2

* remove .DS_Store

# CHANGES IN VERSION 0.99.1

* decrease the size of the package
* simplify and add parameter anchor for the estimatePsite function.
* add parameter normByLibSize for function translationalEfficiency
* add more test files.
* update documentations.

# CHANGES IN VERSION 0.99.0

* Submit to Bioconductor.

# CHANGES IN VERSION 0.0.6

* Remove sapply.

# CHANGES IN VERSION 0.0.1

* Create the package.
